@@ -28,18 +28,12 @@ References:
 Thanks
 ======
 
-I wish to thank the following people for their input:
- * Bas van Oostveen (trbs)
- * Peter van Dijk (Habbie)
- * Hans van Kranenburg (Knorrie)
- * Jeroen Habraken (VeXocide)
- * Torbjörn Lönnemark (tobbez)
- * Anthony Cornehl (twinshadow)
- * Florian Pelgrim (craneworks)
+Thanks to all who have contributed:
 
+https://github.com/tehmaze/ipcalc/graphs/contributors
 '''
 
-__version__ = '1.1.1'
+__version__ = '1.1.2'
 
 
 import warnings
@@ -343,6 +337,25 @@ class IP(object):
         '''
         return self.dq
 
+    def __repr__(self):
+        '''
+        Return canonical representation of the IP.
+
+        >>> ip = IP("::1")
+        >>> print repr(ip)
+        IP('0000:0000:0000:0000:0000:0000:0000:0001', mask=128, version=6)
+        '''
+        return "%s('%s', mask=%d, version=%d)" % (
+                        self.__class__.__name__,
+                        self.dq,
+                        self.mask,
+                        self.v)
+
+    def __hash__(self):
+        return hash(self.to_tuple())
+
+    hash = __hash__
+
     def __int__(self):
         return int(self.ip)
 
@@ -372,8 +385,16 @@ class IP(object):
         Return a new <IP> object with a copy of this one.
 
         >>> ip = IP('127.0.0.1')
-        >>> ip.clone() # doctest: +ELLIPSIS
-        <ipcalc.IP object at 0x...>
+        >>> ip2 = ip.clone()
+        >>> ip2
+        IP('127.0.0.1', mask=32, version=4)
+        >>> ip is ip2
+        False
+        >>> ip == ip2
+        True
+        >>> ip.mask = 24
+        >>> ip2.mask
+        32
         '''
         return IP(self)
 
@@ -642,10 +663,8 @@ class Network(IP):
         >>> for ip in Network('192.168.114.0/30'):
         ...     print str(ip)
         ...
-        192.168.114.0
         192.168.114.1
         192.168.114.2
-        192.168.114.3
         '''
 
         curr = long(self.host_first())
